<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>PanelScreenSaver</name>
    <message>
        <source>Panel Screensaver Global shorcut: &apos;%1&apos; cannot be registered</source>
        <translation>Globálna klávesová skratka Panelu šetriča: „%1“ nemožno zaregistrovať</translation>
    </message>
</context>
</TS>